#!/usr/bin/perl

#===============================================================================
#     REVISION:  $Id: test1.pl 56 2011-02-25 21:48:58Z xdr.box $
#  DESCRIPTION:  Some violations
#===============================================================================

#use strict;
#use warnings;

our $VERSION = '1.0';

sub main {
    return;
}

main();
